# Authsignal Server Python SDK

[Authsignal](https://www.authsignal.com/?utm_source=github&utm_medium=python_sdk) provides passwordless step up authentication (Multi-factor Authentication - MFA) that can be placed anywhere within your application. Authsignal also provides a no-code fraud risk rules engine to manage when step up challenges are triggered.

## Installation

Python 3

```bash
pip3 install authsignal
```

or install newest source directly from GitHub:

```bash
pip3 install git+https://github.com/authsignal/authsignal-python
```

## Documentation

Check out our [getting started guide](https://docs.authsignal.com/api/server-api) for documentation on how to get up and running quickly.

Or browse the [full documentation](https://docs.authsignal.com/sdks/server/python) for the Python client.
